# notedata

在学习和工作过程中，经常用到一些比较通用的数据集，很多是国外的数据集，下载很慢。
这里整理一些数据，并转存到蓝奏云，如果后续有免费的公有云，也可以再迁移到其他云盘。



|序号|分类|名称|描述|官网下载|蓝奏下载|
|:-:|:-:|:-:|:-:|:-:|:-:|
|0|dataset|iris|iris数据集|[官网链接](https://archive.ics.uci.edu/ml/machine-learning-databases/iris/iris.data)|暂无|
|1|dataset|electronics-reviews|Amazon评论数据|[官网链接](http://snap.stanford.edu/data/amazon/productGraph/categoryFiles/reviews_Electronics_5.json.gz)|暂无|
|2|dataset|electronics-meta|Amazon评论数据|[官网链接](http://snap.stanford.edu/data/amazon/productGraph/categoryFiles/meta_Electronics.json.gz)|暂无|
|3|dataset|movielens-100k|包含用户对电影的评级数据、电影元数据信息和用户属性信息|[官网链接](http://files.grouplens.org/datasets/movielens/ml-100k.zip)|[蓝奏链接](https://wws.lanzous.com/iyykCfbi64j)|
|4|dataset|movielens-1m|包含用户对电影的评级数据、电影元数据信息和用户属性信息|[官网链接](http://files.grouplens.org/datasets/movielens/ml-1m.zip)|[蓝奏链接](https://wws.lanzous.com/ihoSUfbi65a)|
|5|dataset|movielens-10m|包含用户对电影的评级数据、电影元数据信息和用户属性信息|[官网链接](http://files.grouplens.org/datasets/movielens/ml-10m.zip)|[蓝奏链接](https://wws.lanzous.com/iXvEmfbi6di)|
|6|dataset|movielens-20m|包含用户对电影的评级数据、电影元数据信息和用户属性信息|[官网链接](http://files.grouplens.org/datasets/movielens/ml-20m.zip)|[蓝奏链接](https://wws.lanzous.com/b01hkt17g)|
|7|dataset|movielens-25m|包含用户对电影的评级数据、电影元数据信息和用户属性信息|[官网链接](http://files.grouplens.org/datasets/movielens/ml-25m.zip)|[蓝奏链接](https://wws.lanzous.com/b01hkt24j)|
|8|dataset|adult-train||[官网链接](https://raw.githubusercontent.com/1007530194/data/master/recommendation/data/adult.data.txt)|暂无|
|9|dataset|adult-test||[官网链接](https://raw.githubusercontent.com/1007530194/data/master/recommendation/data/adult.test.txt)|暂无|
|10|dataset|porto-seguro-train||[官网链接](https://raw.githubusercontent.com/1007530194/data/master/recommendation/data/porto_seguro_train.csv)|暂无|
|11|dataset|porto-seguro-test||[官网链接](https://raw.githubusercontent.com/1007530194/data/master/recommendation/data/porto_seguro_test.csv)|暂无|
|12|dataset|bitly-usagov||[官网链接](https://raw.githubusercontent.com/1007530194/data/master/datasets/bitly_usagov/example.txt)|暂无|
|13|dataset|coco-val2017|大型图像数据集, 用于对象检测、分割、人体关键点检测、语义分割和字幕生成|[官网链接](http://images.cocodataset.org/zips/val2017.zip)|[蓝奏链接](https://wws.lanzous.com/b01hkb8fi)|
|14|dataset|coco-annotations_trainval2017|大型图像数据集, 用于对象检测、分割、人体关键点检测、语义分割和字幕生成|[官网链接](http://images.cocodataset.org/annotations/annotations_trainval2017.zip)|[蓝奏链接](https://wws.lanzous.com/b01hkb86j)|
|15|model|yolov3.weight|yolov3模型的权重|暂无|[蓝奏链接](https://wws.lanzous.com/b01hjn3ih)|
|16|model|yolov3.h5|yolov3模型的权重|暂无|[蓝奏链接](https://wws.lanzous.com/b01hjn3aj)|
|17|model|yolov4.weight|yolov4模型的权重|暂无|[蓝奏链接](https://wws.lanzous.com/b01hjn3yd)|
|18|model|yolov4-416.h5|yolov4模型的权重|暂无|[蓝奏链接](https://wws.lanzous.com/b01hl9lej)|


注：蓝奏无法上传大于100MB的数据，将一个数据拆分为多个文件上传，必须用[notedrive](https://github.com/notechats/notedrive) 来下载


# 感谢
感谢蓝奏云  
